@@ -28,7 +28,7 @@ class ReportType:
         filters = set(filters)
 
         if metrics != "all":
-            diff = set(metrics) - self.metrics
+            diff = set(metrics) - set(self.metrics)
             if diff:
                 raise InvalidRequest("unexpected metric(s): " + ", ".join(diff))
 
@@ -42,7 +42,7 @@ class ReportType:
 
         for amount, values in self.dimensions:
             similarities = len(dimensions & values)
-            if amount == FeatureAmount.REQUIRED and dimensions != values:
+            if amount == FeatureAmount.REQUIRED and similarities != len(values):
                 raise InvalidRequest(f"expected all dimensions from '{', '.join(values)}'")
             elif amount == FeatureAmount.ZERO_OR_ONE and similarities > 1:
                 raise InvalidRequest(f"expected 0 or 1 dimensions from '{', '.join(values)}', got {len(dimensions)}")
@@ -55,7 +55,7 @@ class ReportType:
 
         for amount, values in self.filters:
             similarities = len(filters & values)
-            if amount == FeatureAmount.REQUIRED and filters != values:
+            if amount == FeatureAmount.REQUIRED and similarities != len(values):
                 raise InvalidRequest(f"expected all filters from '{', '.join(values)}'")
             elif amount == FeatureAmount.ZERO_OR_ONE and similarities > 1:
                 raise InvalidRequest(f"expected 0 or 1 filters from '{', '.join(values)}', got {len(filters)}")
@@ -179,7 +179,7 @@ class PlaybackDetailsSubscribedStatusUS(ReportType):
             (FeatureAmount.ZERO_OR_ONE, {"subscribedStatus"}),
             (FeatureAmount.ZERO_OR_ONE, {"day", "month"}),
         ]
-        self.metrics = {
+        self.metrics = (
             "views",
             "redViews",
             "estimatedMinutesWatched",
@@ -199,7 +199,7 @@ class PlaybackDetailsSubscribedStatusUS(ReportType):
             "cardTeaserImpressions",
             "cardClicks",
             "cardTeaserClicks",
-        }
+        )
         self.filters = [
             (FeatureAmount.ZERO_OR_ONE, {"video", "group"}),
             (FeatureAmount.ANY, {"province", "subscribedStatus"}),
@@ -465,7 +465,7 @@ class ViewerDemographics(ReportType):
             (FeatureAmount.NON_ZERO, {"ageGroup", "gender"}),
             (FeatureAmount.ANY, {"liveOrOnDemand", "subscribedStatus"}),
         ]
-        self.metrics = {"viewerPercentage"}
+        self.metrics = ("viewerPercentage",)
         self.filters = [
             (FeatureAmount.ZERO_OR_ONE, {"country", "province", "continent", "subContinent"}),
             (FeatureAmount.ZERO_OR_ONE, {"video", "group"}),
@@ -482,7 +482,7 @@ class EngagementAndContentSharing(ReportType):
             (FeatureAmount.REQUIRED, {"sharingService"}),
             (FeatureAmount.ZERO_OR_ONE, {"subscribedStatus"}),
         ]
-        self.metrics = {"shares"}
+        self.metrics = ("shares",)
         self.filters = [(FeatureAmount.ZERO_OR_ONE, {"country", "continent", "subContinent"}), Detail]
 
     def __str__(self):
@@ -492,7 +492,7 @@ class EngagementAndContentSharing(ReportType):
 class AudienceRetention(ReportType):
     def __init__(self):
         self.dimensions = [(FeatureAmount.REQUIRED, {"elaspedVideoTimeRatio"})]
-        self.metrics = {"audienceWatchRatio", "relativeRetentionPerformance"}
+        self.metrics = ("audienceWatchRatio", "relativeRetentionPerformance")
         self.filters = [
             (FeatureAmount.REQUIRED, {"video"}),
             (FeatureAmount.ANY, {"audienceType", "subscribedStatus", "youtubeProduct"}),
